pub enum CommitBlockError {
Duplicate {
hash_or_height: Option<HashOrHeight>,
location: KnownBlock,
},
ValidateContextError(Box<ValidateContextError>),
#[non_exhaustive] WriteTaskExited,
}Expand description
An error describing why a block could not be queued to be committed to the state.
Variants
Duplicate
The block is a duplicate: it is already queued or committed in the state.
Fields
hash_or_height: Option<HashOrHeight>Hash or height of the duplicated block.
location: KnownBlockLocation in the state where the block can be found.
ValidateContextError(Box<ValidateContextError>)
Contextual validation failed.
#[non_exhaustive]WriteTaskExited
The write task exited (likely during shutdown).
Implementations
Sourceimpl CommitBlockError
impl CommitBlockError
Sourcepub fn new_duplicate(
hash_or_height: Option<HashOrHeight>,
location: KnownBlock,
) -> Self
pub fn new_duplicate( hash_or_height: Option<HashOrHeight>, location: KnownBlock, ) -> Self
Constructs a new CommitBlockError::Duplicate.
Sourceimpl CommitBlockError
impl CommitBlockError
Sourcepub fn new_validate_context_error(f0: Box<ValidateContextError>) -> Self
pub fn new_validate_context_error(f0: Box<ValidateContextError>) -> Self
Constructs a new CommitBlockError::ValidateContextError.
Sourceimpl CommitBlockError
impl CommitBlockError
Sourcepub fn new_write_task_exited() -> Self
pub fn new_write_task_exited() -> Self
Constructs a new CommitBlockError::WriteTaskExited.
Sourceimpl CommitBlockError
impl CommitBlockError
Sourcepub fn is_duplicate_request(&self) -> bool
pub fn is_duplicate_request(&self) -> bool
Returns true if this is definitely a duplicate commit request.
Some duplicate requests might not be detected, and therefore return false.