#[non_exhaustive]pub enum ReconsiderError {
MissingInvalidatedBlock(Hash),
ParentChainNotFound(Hash),
InvalidatedBlocksEmpty,
CheckpointCommitInProgress,
ReconsiderSendFailed,
ReconsiderResponseDropped,
}Expand description
An error describing why a ReconsiderBlock request failed.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
MissingInvalidatedBlock(Hash)
The block is not found in the list of invalidated blocks.
ParentChainNotFound(Hash)
The block’s parent is missing from the non-finalized state.
InvalidatedBlocksEmpty
There were no invalidated blocks when at least one was expected.
CheckpointCommitInProgress
The state is currently checkpointing blocks and cannot accept reconsider requests.
ReconsiderSendFailed
Sending the reconsider request to the block write task failed.
ReconsiderResponseDropped
The reconsider request was dropped before processing.